@@ -23,6 +23,11 @@ pub struct CommonContextsOpt {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub name: Option<String>,
 
+    /// Target context name pattern (SQL LIKE statement value).
+    #[structopt(long, requires("type-name"), conflicts_with("name"))]
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub name_pattern: Option<String>,
+
     /// Target context type.
     #[structopt(long = "type")]
     #[serde(rename = "type")]
@@ -70,11 +75,14 @@ impl CommonContextsOpt {
         if !self.ids.is_empty() {
             request = request.ids(self.ids.iter().copied().map(mlmd::metadata::ContextId::new));
         }
-        match (&self.name, &self.type_name) {
-            (Some(name), Some(type_name)) => {
+        match (&self.name, &self.name_pattern, &self.type_name) {
+            (Some(name), None, Some(type_name)) => {
                 request = request.type_and_name(type_name, name);
             }
-            (None, Some(type_name)) => {
+            (None, Some(name_pattern), Some(type_name)) => {
+                request = request.type_and_name_pattern(type_name, name_pattern);
+            }
+            (None, None, Some(type_name)) => {
                 request = request.ty(type_name);
             }
             _ => {}
